@@ -3,6 +3,7 @@
 from json import dumps
 
 from mcipc.rcon.datastructures import Help, Location, Players, Seed
+from mcipc.rcon.exceptions import InvalidStructure, NotALocation
 from mcipc.rcon.proto import Client as _Client
 
 
@@ -26,7 +27,9 @@ class AdminMixin:
 
     def teleport(self, player: str, *, dst_player: str = None,
                  coords: tuple = None, orientation: tuple = None) -> str:
-        """Teleports players."""
+        """Teleports the player to either another
+        player or a set of coordinates.
+        """
         args = [player]
 
         if sum(item is None for item in (dst_player, coords)) != 1:
@@ -64,15 +67,16 @@ class ChatMixin:
         """Broadcast a message to all players."""
         return self.run('say', message)
 
+    def tellraw(self, player: str, obj: dict) -> str:
+        """Sends a message represented by a JSON-ish dict."""
+        return self.run('tellraw', player, dumps(obj))
+
     def send_url(self, player: str, url: str, text: str = None) -> str:
         """Sends a URL to the specified player.
         If text is None, it will default to the original URL.
         """
-        if text is None:
-            text = url
-
         json = {
-            'text': text,
+            'text': text or url,
             'clickEvent': {
                 'action': 'open_url',
                 'value': url
@@ -80,10 +84,6 @@ class ChatMixin:
         }
         return self.tellraw(player, json)
 
-    def tellraw(self, player: str, obj: dict) -> str:
-        """Sends a message represented by a JSON-ish dict."""
-        return self.run('tellraw', player, dumps(obj))
-
 
 class InfoMixin:
     """Server information mixin."""
@@ -114,7 +114,11 @@ class InfoMixin:
     def locate(self, structure: str) -> Location:
         """Locates the respective structure."""
         response = self.run('locate', structure)
-        return Location.from_response(response)
+
+        try:
+            return Location.from_response(response)
+        except NotALocation:
+            raise InvalidStructure(structure)
 
 
 class Client(_Client, AdminMixin, ChatMixin, InfoMixin):
